@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.010005";
+    our $MITE_VERSION = "0.010006";
 
     # Mite keywords
     BEGIN {
@@ -402,7 +402,7 @@
             "\$_[1]", "Defined"
           );
 
-        return ( &$__NEXT__( @head, @_ ) );
+        do { @_ = ( @head, @_ ); goto $__NEXT__ };
     };
 
     1;
