@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.010005";
+    our $MITE_VERSION = "0.010006";
 
     # Mite keywords
     BEGIN {
@@ -327,7 +327,7 @@
           );
         push( @out, $tmp );
 
-        return ( &$__NEXT__( @head, @out ) );
+        do { @_ = ( @head, @out ); goto $__NEXT__ };
     };
 
     $SIGNATURE_FOR{"fix_pm_to_blib"} = sub {
@@ -459,7 +459,7 @@
           );
         push( @out, $tmp );
 
-        return ( &$__NEXT__( @head, @out ) );
+        do { @_ = ( @head, @out ); goto $__NEXT__ };
     };
 
     1;
