@@ -6,7 +6,7 @@ package Mite::Signature;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010005';
+our $VERSION   = '0.010006';
 
 has class =>
   is            => ro,
@@ -99,7 +99,7 @@ sub _build_compiler {
             ( $self->tail ? ( tail => $self->tail ) : () ),
             named_to_list  => $self->named_to_list,
             strictness     => scalar( $self->autolax // 1 ),
-            is_wrapper     => true,
+            goto_next      => true,
             mite_signature => $self,
             $self->should_bless
                 ? ( bless => sprintf '%s::__NAMED_ARGUMENTS__::%s', $self->class->name, $self->method_name )
