@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Role";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.010005";
+    our $MITE_VERSION = "0.010006";
 
     # Mite keywords
     BEGIN {
@@ -139,7 +139,7 @@
           );
         push( @out, $SLURPY );
 
-        return ( &$__NEXT__( @head, @out ) );
+        do { @_ = ( @head, @out ); goto $__NEXT__ };
     };
 
     # Callback which classes consuming this role will call
